summaryrefslogtreecommitdiff
path: root/basic/source/app/msgedit.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'basic/source/app/msgedit.hxx')
-rw-r--r--basic/source/app/msgedit.hxx27
1 files changed, 11 insertions, 16 deletions
diff --git a/basic/source/app/msgedit.hxx b/basic/source/app/msgedit.hxx
index 7dc7117a8b..8d9c703746 100644
--- a/basic/source/app/msgedit.hxx
+++ b/basic/source/app/msgedit.hxx
@@ -38,7 +38,7 @@ class AppError;
#define SelectChildren SelectChilds
-typedef USHORT TTFeatures; // Bitfield for features of the entries
+typedef sal_uInt16 TTFeatures; // Bitfield for features of the entries
#define HasNothing TTFeatures(0x00)
#define HasError TTFeatures(0x01)
#define HasWarning TTFeatures(0x02)
@@ -49,26 +49,21 @@ typedef USHORT TTFeatures; // Bitfield for features of the entries
class TTTreeListBox : public SvTreeListBox
{
protected:
-// virtual void Command( const CommandEvent& rCEvt );
-// USHORT nDeselectParent;
BasicFrame *pBasicFrame;
void InitEntry( SvLBoxEntry*, const String&, const Image&,
const Image&, SvLBoxButtonKind eButtonKind );
AppError *pAppError;
- BOOL JumpToSourcecode( SvLBoxEntry *pThisEntry );
+ sal_Bool JumpToSourcecode( SvLBoxEntry *pThisEntry );
public:
TTTreeListBox( AppError* pParent, BasicFrame* pBF, WinBits nWinStyle=0 );
~TTTreeListBox(){}
-// virtual void SelectHdl();
-// virtual void DeselectHdl();
- virtual BOOL DoubleClickHdl();
+ virtual sal_Bool DoubleClickHdl();
virtual void KeyInput( const KeyEvent& rKEvt );
-// ULONG SelectChildren( SvLBoxEntry* pParent, BOOL bSelect );
TTFeatures GetFeatures( SvLBoxEntry* );
};
@@ -80,20 +75,20 @@ class MsgEdit : public DataEdit
SvLBoxEntry *pCurrentTestCase;
SvLBoxEntry *pCurrentAssertion;
SvLBoxEntry *pCurrentError;
- BOOL bModified;
+ sal_Bool bModified;
Link lModify;
- BOOL bFileLoading; // TRUE while loading a file
+ sal_Bool bFileLoading; // sal_True while loading a file
String Impl_MakeText( SvLBoxEntry *pEntry ) const;
String Impl_MakeSaveText( SvLBoxEntry *pEntry ) const;
String Impl_MakeSaveText( TTDebugData aData ) const;
- USHORT nVersion; // Stores file version
+ sal_uInt16 nVersion; // Stores file version
AppError* pAppError;
String aLogFileName;
- static USHORT nMaxLogLen;
- static BOOL bLimitLogLen;
- static BOOL bPrintLogToStdout;
- static BOOL bPrintLogToStdoutSet; // has it been initialized yet
+ static sal_uInt16 nMaxLogLen;
+ static sal_Bool bLimitLogLen;
+ static sal_Bool bPrintLogToStdout;
+ static sal_Bool bPrintLogToStdoutSet; // has it been initialized yet
public:
MsgEdit( AppError*, BasicFrame *pBF, const WinBits& );
~MsgEdit();
@@ -108,7 +103,7 @@ public:
void AddAssertionStack( String aMsg, TTDebugData aDebugData );
void AddQAError( String aMsg, TTDebugData aDebugData );
- static void SetMaxLogLen( USHORT nLen ) { nMaxLogLen = nLen; bLimitLogLen = TRUE; }
+ static void SetMaxLogLen( sal_uInt16 nLen ) { nMaxLogLen = nLen; bLimitLogLen = sal_True; }
DATA_FUNC_DEF( aEditTree, TTTreeListBox )
};